# -*- coding: utf-8 -*-
from trac.ticket import ITicketChangeListener, Ticket, ITicketManipulator
from trac.config import Option, Configuration
from trac.core import *
import time
import datetime


class CompleteTicketObserver(Component):
    implements(ITicketChangeListener)

    complete_conditions = Option('ganttcalendar', 'complete_conditions', '100,00', u"""Valid Resolutions for auto completion""")
    complete_field = Option('ganttcalendar', 'complete_field', 'complete', u"""Fields set the rate of progress""")

    def __init__(self):
        pass

    def ticket_created(self, ticket):
        pass

    def ticket_deleted(self, ticket):
        pass

    def ticket_changed(self, ticket, comment, author, old_values):
        complete_conditions = Configuration.getlist(self.config,'ganttcalendar','complete_conditions',"'fixed,invalid,wontfix'")
        complete_field = Configuration.get(self.config,'ganttcalendar','complete_field','complete')

        self.env.log.debug("complete_conditions: %s" % complete_conditions)
        self.env.log.debug("status: %s" % ticket.values['status'])
        self.env.log.debug("complete: %s" % ticket.values[complete_field])

        if complete_conditions == None or ticket.values['status'] != 'closed':
            return 

        complete_flag = False

        for cc in complete_conditions:
           if ticket.values['resolution'] == cc:
               complete_flag = True

        if complete_flag:
            ticket.values[complete_field] = 100
            db = self.env.get_db_cnx()
            cursor = db.cursor()
            save_custom_field_value(db, ticket.id, 'complete', ticket.values[complete_field])
            db.commit()
            today = datetime.date.today()
            save_custom_field_value(db, ticket.id, 'due_close', today .strftime("%Y/%m/%d"))
            db.commit()

        self.env.log.debug("flag: %s" % complete_flag)
        self.env.log.debug("complete(after): %s" % ticket.values[complete_field])

def save_custom_field_value( db, ticket_id, field, value ):
    cursor = db.cursor()
    cursor.execute("SELECT * FROM ticket_custom "
                   "WHERE ticket=%s and name=%s", (ticket_id, field))
    if cursor.fetchone():
        cursor.execute("UPDATE ticket_custom SET value=%s "
                       "WHERE ticket=%s AND name=%s",
                       (value, ticket_id, field))
    else:
        cursor.execute("INSERT INTO ticket_custom (ticket,name, "
                       "value) VALUES(%s,%s,%s)",
                       (ticket_id, field, value))

